@@ -38,11 +38,11 @@ overlap3d <- function(colsp1, colsp2, avalue = "auto", plot = FALSE,
                       interactive = TRUE, col = c("blue", "red", "darkgrey"),
                       fill = FALSE, new = TRUE, nsamp = 1000, psize = 0.001,
                       lwd = 1, ...) {
-
   if (!requireNamespace("alphashape3d", quietly = TRUE)) {
     stop(
       "Please install the alphashape3d package to be able to use ",
-      "this function", call. = FALSE
+      "this function",
+      call. = FALSE
     )
   }
 
@@ -107,8 +107,8 @@ overlap3d <- function(colsp1, colsp2, avalue = "auto", plot = FALSE,
   if (plot) {
     if (!interactive) {
       warning(
-        "interactive = FALSE has not been implemented yet, falling back to",
-        " interactive plot."
+        "interactive = FALSE has not been implemented yet,\n",
+        "falling back tointeractive plot.", call. = FALSE
       )
     }
     if (length(col) < 3) {
