@@ -29,7 +29,6 @@ test_that("as.rimg", {
   # Warnings/messages
   expect_message(as.rimg(imgfake), "[0,1]")
   expect_message(as.rimg(imgfake2), "[0,1]")
-  expect_warning(getimg(system.file("testdata/images/papilio.png", package = "pavo"), cores = 2), "deprecated")
 
   # Classes/attributes/structure
   expect_equal(dim(rimgfake), c(10, 10, 3))
@@ -46,7 +45,7 @@ test_that("as.rimg", {
   expect_true(is.rimg(rimggrey))
 
   # as.rimg can handle user-classified images
-  papilio <- getimg(system.file("testdata/images/papilio.png", package = "pavo"))
+  papilio <- getimg(system.file("testdata/images/butterflies/papilio.png", package = "pavo"))
   papilio_class <- classify(papilio, kcols = 4)
   pap2 <- as.rimg(matrix(papilio_class, nrow = (nrow(papilio_class)), ncol = ncol(papilio_class)))
   expect_true(is.rimg(pap2))
@@ -61,7 +60,7 @@ test_that("as.rimg", {
 })
 
 test_that("procimg", {
-  papilio <- getimg(system.file("testdata/images/papilio.png", package = "pavo"))
+  papilio <- getimg(system.file("testdata/images/butterflies/papilio.png", package = "pavo"))
 
   # Resize
   expect_equal(dim(procimg(papilio, resize = 50))[1:2], dim(papilio)[1:2] / 2)
@@ -74,6 +73,14 @@ test_that("procimg", {
   expect_message(procimg(papilio, "coerce"))
   class(papilio) <- "cimg"
   expect_message(procimg(papilio, "coerce"))
+  
+  # Acuity
+  expect_warning(procimg(papilio, obj_dist = 3), "Skipping")
+  expect_warning(procimg(papilio, obj_width = 3), "Skipping")
+  expect_warning(procimg(papilio, eye_res = 3), "Skipping")
+  expect_warning(procimg(papilio, obj_width = 3, obj_dist = 3), "Skipping")
+  expect_warning(procimg(papilio, obj_width = 'black', obj_dist = 3, eye_res = 10), "Skipping")
+  expect_warning(procimg(classify(papilio, kcols = 3), obj_width = 3, obj_dist = 3, eye_res = 10), "Skipping")
 })
 
 
@@ -268,7 +275,7 @@ test_that("adjacency", {
   expect_equal(checker_adj$m_lum, 5.68)
 
   # Can handle user-classified images
-  papilio <- getimg(system.file("testdata/images/papilio.png", package = "pavo"))
+  papilio <- getimg(system.file("testdata/images/butterflies/papilio.png", package = "pavo"))
   papilio_class <- classify(papilio, kcols = 4)
   papilio_adj <- adjacent(papilio_class, xscale = 100)
 
@@ -281,14 +288,14 @@ test_that("adjacency", {
 # test_that("summary", {
 #   suppressWarnings(RNGversion("3.5.0")) # back compatibility for now
 #   set.seed(2231)
-# 
-#   papilio <- getimg(system.file("testdata/images/papilio.png", package = "pavo"))
+#
+#   papilio <- getimg(system.file("testdata/images/butterflies/papilio.png", package = "pavo"))
 #   papilio_class <- classify(papilio, kcols = 4)
 #   snakes <- getimg(system.file("testdata/images/snakes", package = "pavo"))
 #   snakes_class <- classify(snakes, kcols = 3)
-# 
+#
 #   expect_equal(summary(papilio_class)[1:3], data.frame(rep("papilio", 4), 1:4, 1:4, stringsAsFactors = FALSE), ignore_attr = TRUE)
-# 
+#
 #   truth <- c(3.621, 1.827, 0.159)
 #   expect_equal(colSums(round(summary(snakes_class)[4:6], 3)), truth, ignore_attr = TRUE)
 # })
